==> 1.2.1.tar.gz: lib/src/cruiser_page_route.dart <==
import 'package:cruiser/cruiser.dart';
import 'package:cruiser/src/models/cruiser_transition.dart';
import 'package:cruiser/src/transitions/cube_transition.dart';
import 'package:cruiser/src/transitions/depth_transition.dart';
import 'package:cruiser/src/transitions/parallax_transition.dart';
import 'package:cruiser/src/transitions/tablet_transition.dart';
import 'package:flutter/material.dart';
import 'package:cruiser/src/transitions/slide_transition.dart' as slide;

class CruiserPageRoute extends PageRouteBuilder 
{
    final TransitionType transition;
    final Cruiser router;

    CruiserPageRoute({
        @required RouteSettings settings,
        @required this.transition,
        @required WidgetBuilder builder,
        @required this.router,
        Duration transitionDuration = const Duration(milliseconds: 600),
        bool opaque = true,
        bool barrierDismissible = false,
        Color barrierColor,
        String barrierLabel,
        bool maintainState = true,
        bool fullscreenDialog = false,
    }) : super(
        settings: settings,
        pageBuilder: (context, anim1, anim2) => builder(context),
        transitionDuration: transitionDuration,
        opaque: opaque,
        barrierDismissible: barrierDismissible,
        barrierColor: barrierColor,
        barrierLabel: barrierLabel,
        maintainState: maintainState,
        fullscreenDialog: fullscreenDialog,
    );

    @override
    Widget buildTransitions(BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Widget child) 
    {
        var cruiserTransition = getTransition();

        return cruiserTransition?.build(context, animation, secondaryAnimation, child);
    }

    CruiserTransition getTransition()
    {
        switch(router.currentTransition)
        {
            case TransitionType.slide: return slide.SlideTransition();
            case TransitionType.cube: return CubeTransition();
            case TransitionType.zoomIn: return ZoomInTransition();
            case TransitionType.accordion: return AccordionTransition();
            case TransitionType.backgroundToForeground: return BackgroundToForegroundTransition();
            case TransitionType.flipHorizontal: return FlipHorizontalTransition();
            case TransitionType.flipVertical: return FlipVerticalTransition();
            case TransitionType.foregroundToBackground: return ForegroundToBackgroundTransition();
            case TransitionType.parallax: return ParallaxTransition();
            case TransitionType.rotateDown: return RotateDownTransition();
            case TransitionType.rotateUp: return RotateUpTransition();
            case TransitionType.stack: return StackTransition();
            case TransitionType.tablet: return TabletTransition();
            case TransitionType.zoomOutSlide: return ZoomOutSlideTransition();
            case TransitionType.depth:  return DepthTransition();
            default: throw new Exception('${router.currentTransition} transition not found');
        }
    }
}

==> 1.2.3.tar.gz: lib/src/cruiser_page_route.dart <==
import 'package:cruiser/cruiser.dart';
import 'package:cruiser/src/models/cruiser_transition.dart';
import 'package:cruiser/src/transitions/cube_transition.dart';
import 'package:cruiser/src/transitions/depth_transition.dart';
import 'package:cruiser/src/transitions/parallax_left.dart';
import 'package:cruiser/src/transitions/parallax_top.dart';
import 'package:cruiser/src/transitions/tablet_transition.dart';
import 'package:flutter/material.dart';
import 'package:cruiser/src/transitions/slide_transition.dart' as slide;

class CruiserPageRoute extends PageRouteBuilder 
{
    final TransitionType transition;
    final Cruiser router;

    CruiserPageRoute({
        @required RouteSettings settings,
        @required this.transition,
        @required WidgetBuilder builder,
        @required this.router,
        Duration transitionDuration = const Duration(milliseconds: 500),
        bool opaque = true,
        bool barrierDismissible = false,
        Color barrierColor,
        String barrierLabel,
        bool maintainState = true,
        bool fullscreenDialog = false,
    }) : super(
        settings: settings,
        pageBuilder: (context, anim1, anim2) => builder(context),
        transitionDuration: transitionDuration,
        opaque: opaque,
        barrierDismissible: barrierDismissible,
        barrierColor: barrierColor,
        barrierLabel: barrierLabel,
        maintainState: maintainState,
        fullscreenDialog: fullscreenDialog,
    );

    @override
    Widget buildTransitions(BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation, Widget child) 
    {
        var cruiserTransition = getTransition();

        return cruiserTransition?.build(context, animation, secondaryAnimation, child);
    }

    CruiserTransition getTransition()
    {
        switch(router.currentTransition)
        {
            case TransitionType.slide: return slide.SlideTransition();
            case TransitionType.cube: return CubeTransition();
            case TransitionType.zoomIn: return ZoomInTransition();
            case TransitionType.accordion: return AccordionTransition();
            case TransitionType.backgroundToForeground: return BackgroundToForegroundTransition();
            case TransitionType.flipHorizontal: return FlipHorizontalTransition();
            case TransitionType.flipVertical: return FlipVerticalTransition();
            case TransitionType.foregroundToBackground: return ForegroundToBackgroundTransition();
            case TransitionType.parallaxLeft: return ParallaxLeft();
            case TransitionType.parallaxTop: return ParallaxTop();
            case TransitionType.rotateDown: return RotateDownTransition();
            case TransitionType.rotateUp: return RotateUpTransition();
            case TransitionType.stack: return StackTransition();
            case TransitionType.tablet: return TabletTransition();
            case TransitionType.zoomOutSlide: return ZoomOutSlideTransition();
            case TransitionType.depth:  return DepthTransition();
            default: throw new Exception('${router.currentTransition} transition not found');
        }
    }
}
